==> ExternalStorage-0.1.tgz: ExternalStorage-0.1/ExternalStorage/tests/testFunctional.py <==
#
# Functional Tests
#

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from Testing import ZopeTestCase

from Products.ExternalStorage.tests import ESTestCase

ZopeTestCase.utils.setupCoreSessions()


class TestDownload(ESTestCase.FunctionalTestCase):

    def afterSetUp(self):
        self.portal_path = '/' + self.portal.absolute_url(1)
        self.art = self._addFileByFileUpload(self.folder, 'file',
                                             ESTestCase.FILENAME_DOC)
        self._updateContent(self.art, 'file_normal', ESTestCase.DATAPATH_ZIP)
        self.art_url = '/' + self.art.absolute_url(1)
        self.basic_auth = '%s:%s' % (ESTestCase.default_user,
                                     ESTestCase.default_password)

    def testArchetypesAnonymousAttributeStorageDownload(self):
        content = str(self.art.getFile_normal())
        response = self.publish(self.art_url+'/file_normal/at_download')
        self.assertEqual(response.getStatus(), 200)
        body = response.getBody()
        self.failUnlessEqual(body, content)


    def testArchetypesAuthenticatedAttributeStorageDownload(self):
        content = str(self.art.getFile_normal())
        response = self.publish(self.art_url+'/file_normal/at_download',
                                self.basic_auth)
        self.assertEqual(response.getStatus(), 200)
        body = response.getBody()
        self.failUnlessEqual(body, content)

        # This 2 tests actually fails. AFAIK, there is two possible solutions:
        #
        # 1) Change ExternalStorage.ExternalStorage.initializeField to make the
        #    field name a computed attribute in the instance. Something like:
        #
        #    @@ -193,6 +193,9 @@
        #         security.declarePrivate('initializeField')
        #         def initializeField(self, instance, field):
        #             log("initializeField: %s" % field)
        #    +        if not hasattr(aq_base(instance), name):
        #    +            from ComputedAttribute import ComputedAttribute
        #    +            setattr(instance, name, ComputedAttribute(field.get))
        #
        #         security.declarePrivate('cleanupField')
        #         def cleanupField(self, instance, field, **kwargs):
        #
        #    This makes tests pass, but also makes Zope SEGFAULT... :-(
        #
        # 2) Change Archetypes.BaseObject._bobo_traverse__ to explicitly
        #    call accessors for FileFields:
        #
        #    @@ -931,8 +929,12 @@
        #                 if shasattr(self, name):
        #                     target = getattr(self, name)
        #             else:
        #    -            # we are allowed to acquire
        #    -            target = getattr(self, name, None)
        #    +            field = self.getField(name)
        #    +            if IFileField.isImplementedBy(field):
        #    +                target = field.get(self)
        #    +            else:
        #    +                # we are allowed to acquire
        #    +                target = getattr(self, name, None)
        #             if target is not None:
        #                 return target
        #             if (method in ('PUT', 'MKCOL') and not
        #
        #    This works great, and I'm discussing to get a +2... ;-)

    def testArchetypesAnonymousExternalStorageDownload(self):
        content = str(self.art.getFile())
        response = self.publish(self.art_url+'/file/at_download')
        self.assertEqual(response.getStatus(), 200)
        body = response.getBody()
        self.failUnlessEqual(body, content)


    def testArchetypesAuthenticatedExternalStorageDownload(self):
        content = str(self.art.getFile())
        response = self.publish(self.art_url+'/file/at_download',
                                self.basic_auth)
        self.assertEqual(response.getStatus(), 200)
        body = response.getBody()
        self.failUnlessEqual(body, content)


def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestDownload))
    return suite

if __name__ == '__main__':
    framework()

==> ExternalStorage-0.5.tgz: ExternalStorage-0.5/ExternalStorage/tests/testFunctional.py <==
#
# Functional Tests
#

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from Testing import ZopeTestCase

from Products.ExternalStorage.tests import ESTestCase

ZopeTestCase.utils.setupCoreSessions()


class TestDownload(ESTestCase.FunctionalTestCase):

    def afterSetUp(self):
        self.portal_path = '/' + self.portal.absolute_url(1)
        self.complex = self._addFileByFileUpload(self.folder, 'file_external1',
                                                 ESTestCase.FILENAME_DOC,
                                                 'ComplexSample')
        self._updateContent(self.complex, 'file_normal', ESTestCase.DATAPATH_ZIP)
        self.complex_url = '/' + self.complex.absolute_url(1)
        self.basic_auth = '%s:%s' % (ESTestCase.default_user,
                                     ESTestCase.default_password)

    def testArchetypesAnonymousAttributeStorageDownload(self):
        content = str(self.complex.getFile_normal())
        response = self.publish(self.complex_url+'/at_download/file_normal')
        self.assertEqual(response.getStatus(), 200)
        body = response.getBody()
        self.failUnlessEqual(body, content)


    def testArchetypesAuthenticatedAttributeStorageDownload(self):
        content = str(self.complex.getFile_normal())
        response = self.publish(self.complex_url+'/at_download/file_normal',
                                self.basic_auth)
        self.assertEqual(response.getStatus(), 200)
        body = response.getBody()
        self.failUnlessEqual(body, content)

        # This 2 tests actually fails. AFAIK, there is two possible solutions:
        #
        # 1) Change ExternalStorage.ExternalStorage.initializeField to make the
        #    field name a computed attribute in the instance. Something like:
        #
        #    @@ -193,6 +193,9 @@
        #         security.declarePrivate('initializeField')
        #         def initializeField(self, instance, field):
        #             log("initializeField: %s" % field)
        #    +        if not hasattr(aq_base(instance), name):
        #    +            from ComputedAttribute import ComputedAttribute
        #    +            setattr(instance, name, ComputedAttribute(field.get))
        #
        #         security.declarePrivate('cleanupField')
        #         def cleanupField(self, instance, field, **kwargs):
        #
        #    This makes tests pass, but also makes Zope SEGFAULT... :-(
        #
        # 2) Change Archetypes.BaseObject._bobo_traverse__ to explicitly
        #    call accessors for FileFields:
        #
        #    @@ -931,8 +929,12 @@
        #                 if shasattr(self, name):
        #                     target = getattr(self, name)
        #             else:
        #    -            # we are allowed to acquire
        #    -            target = getattr(self, name, None)
        #    +            field = self.getField(name)
        #    +            if IFileField.isImplementedBy(field):
        #    +                target = field.get(self)
        #    +            else:
        #    +                # we are allowed to acquire
        #    +                target = getattr(self, name, None)
        #             if target is not None:
        #                 return target
        #             if (method in ('PUT', 'MKCOL') and not
        #
        #    This works great, and I'm discussing to get a +2... ;-)

    def testArchetypesAnonymousExternalStorageDownload(self):
        content = str(self.complex.getFileExternal1())
        response = self.publish(self.complex_url+'/at_download/file_external1')
        self.assertEqual(response.getStatus(), 200)
        body = response.getBody()
        self.failUnlessEqual(body, content)

    def testArchetypesAuthenticatedExternalStorageDownload(self):
        content = str(self.complex.getFileExternal1())
        response = self.publish(self.complex_url+'/at_download/file_external1',
                                self.basic_auth)
        self.assertEqual(response.getStatus(), 200)
        body = response.getBody()
        self.failUnlessEqual(body, content)


def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestDownload))
    return suite

if __name__ == '__main__':
    framework()
